import os
import pickle
import argparse

# The nodes we used are the same as the one from the paper, however, we excluded the nodes that were not applicable to Python based
# on the node types list found here: https://github.com/tree-sitter/tree-sitter-python/blob/master/src/node-types.json
# we also left ERROR node as we found it present in Python ASTs generated by tree-sitter
# we swapped string_literal, number_literal, and char_literal with string, float, and integer
def createDictionary(destFolder):
    dictionaryOfNodes = {
       "!=": "Logical_Operator",
        "%": "Arithmetic_Operator",
        "&": "Pointer_Reference",
        "(": "Bracket",
        ")": "Bracket",
        "*": "Arithmetic_Operator",
        "*=": "Arithmetic_Operator",
        "+": "Arithmetic_Operator",
        "+=": "Arithmetic_Operator",
        ",": "Separator",
        "-": "Arithmetic_Operator",
        "->": "Arrow_Operator",
        ".": "Dot_Operator",
        "/": "Arithmetic_Operator",
        ":": "Separator",
        ";": "Separator",
        "<": "Relational_Operator",
        "<=": "Relational_Operator",
        "=": "Arithmetic_Operator",
        "==": "Relational_Operator",
        ">": "Relational_Operator",
        ">=": "Relational_Operator",
        "?": "Logical_Operator",
        "ERROR": "Error",
        "[": "Bracket",
        "]": "Bracket",
        "argument_list": "Definition",
        "break": "Control_Declarator",
        "break_statement": "Control_Statement",
        "comment": "Comment",
        "conditional_expression": "Expression",
        "continue": "Control_Declarator",
        "continue_statement": "Control_Statement",
        "delete_expression": "Expression",
        "else": "Condition_Keyword",
        "escape_sequence": "Escape_Sequence",
        "expression_statement": "Expression_Statement",
        "for": "Condition_Keyword",
        "for_statement": "Condition_Statement",
        "function_definition": "Function_Definition",
        "identifier": "Identifier",
        "if": "Condition_Keyword",
        "if_statement": "Condition_Statement",
        "not": "Logical_Operator",
        "integer": "Literal", 
        "float": "Literal", 
        "string": "Literal",
        "parenthesized_expression": "Expression",
        "return": "Control_Declarator",
        "return_statement": "Control_Statement",
        "while": "Condition_Keyword",
        "while_statement": "Condition_Statement",
        "{": "Bracket",
        "}": "Bracket",
        "else_clause":"Condition",
        "string_content":"Statement"
    }

    dictPath = os.path.join(destFolder, "DictOfNodes.pickle")

    try:
        os.makedirs(destFolder, exist_ok=True)
        with open(dictPath, "wb") as outF:
            pickle.dump(dictionaryOfNodes, outF)
    except OSError as error:
        print("unable to create")


def main():
    cmdparser = argparse.ArgumentParser()
    cmdparser.add_argument(
        "file", help="Add path for destination folder Node Types set file"
    )

    args = cmdparser.parse_args()
    destFolder = args.file

    createDictionary(destFolder)


if __name__ == "__main__":
    main()